( cd usr/share/doc/HTML/en/kdeskbar ; rm -rf common )
( cd usr/share/doc/HTML/en/kdeskbar ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kdeskbar ; rm -rf common )
( cd usr/share/doc/HTML/en/kdeskbar ; ln -sf /usr/share/doc/HTML/en/common common )
